@@ -4,10 +4,12 @@ from urllib.parse import urljoin
 from itertools import zip_longest
 from .. import regex
 from ..url import Url
+import requests
 
 
 class Parser:
     fetch_method = 'request_advance'
+    oembed_api_url = None
     url = None
     content = None
     meta_dict = {}
@@ -100,6 +102,13 @@ class Parser:
 
         return author
 
+    def fetch_oembed(self):
+        if self.oembed_api_url:
+
+            request_url = self.oembed_api_url.format(url=self.url)
+            response = requests.get(request_url).json()
+            return response
+
     def get_body_images(self):
         body = re.search(regex.body, self.content, flags=re.IGNORECASE)
         image_urls = {'with_extension': [], 'without_extension': []}
