@@ -34,15 +34,13 @@ class Url:
         return self.origin_url
 
     def get_provider(self):
-        return '{}.{}'.format(self.domain.domain, self.domain.suffix)
+        return '.'.join(part for part in [self.domain.domain, self.domain.suffix] if part)
 
     def get_provider_name(self):
         return self.domain.domain
 
     def get_provider_url(self):
-        return '{}://{}.{}.{}'.format(
-            self.get_scheme(), self.domain.subdomain, self.domain.domain, self.domain.suffix
-        )
+        return self.get_scheme() + '://' + '.'.join(part for part in self.domain if part)
 
     def get_properties(self):
         return {
